LANGUAGE_MAP = {
    "en": [
        {
            "modelPath": "stt_model/en/vosk/11-05-2022-06-38-vosk-big-model-light-conf-en-us-0.22.zip",
            "domain": "general",
            "accent": "american",
            "suburl": "en-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need transcriptions that are accurate across domains.\
                 This is the recommended default choice.",
        },
        {
            "modelPath": "stt_model/en/vosk_hub/19-05-2022-03-24-vosk-en-medical-mixed-0.9-us-0.22.zip",
            "accent": "american",
            "domain": "medical",
            "suburl": "en-medical-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need accurate transcriptions especially for medical terms \
                along with commonly spoken words.",
        },
        {
            "modelPath": "stt_model/en/vosk_hub/13-05-2022-07-11-vosk-en-finance-mixed-0.7-us-0.22.zip",
            "accent": "american",
            "domain": "finance",
            "suburl": "en-finance-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need accurate transcriptions especially for financial \
                terms along with commonly spoken words.",
        },
        {
            "modelPath": "stt_model/en-in/vosk_hub/19-05-2022-14-18-vosk-model-en-in-0.5.zip",
            "suburl": "en-in-16",
            "domain": "indian",
            "sampleRate": 16000,
            "description": "Select this domain if you need accurate transcriptions for Indian accented speech.",
        },
    ],
    "hi": [
        {
            "modelPath": "stt_model/hi/vosk_hub/13-05-2022-06-09-vosk-model-hi-0.22.zip",
            "domain": "general",
            "suburl": "hi-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need transcriptions that are accurate across domains.",
        },
    ],
    "sv": [
        {
            "modelPath": "stt_model/sv/vosk_hub/13-05-2022-07-20-vosk-model-small-sv-rhasspy-0.15.zip",
            "domain": "general",
            "suburl": "sv-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need transcriptions that are accurate across domains.",
        }
    ],
    "ar": [
        {
            "modelPath": "stt_model/ar/vosk_hub/13-05-2022-05-08-vosk-model-ar-mgb2-0.4.zip",
            "domain": "general",
            "suburl": "ar-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need transcriptions that are accurate across domains.",
        }
    ],
    "ru": [
        {
            "modelPath": "stt_model/ru/vosk_hub/13-05-2022-07-02-vosk-model-ru-0.22.zip",
            "domain": "general",
            "suburl": "ru-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need transcriptions that are accurate across domains.",
        }
    ],
    "fr": [
        {
            "modelPath": "stt_model/fr/vosk_hub/13-05-2022-06-38-vosk-model-fr-0.22.zip",
            "domain": "general",
            "suburl": "fr-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need transcriptions that are accurate across domains.",
        }
    ],
    "tl": [
        {
            "modelPath": "stt_model/ph/vosk_hub/13-05-2022-07-08-vosk-model-tl-ph-generic-0.6.zip",
            "domain": "general",
            "suburl": "ph-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need transcriptions that are accurate across domains.",
        }
    ],
    "uk": [
        {
            "modelPath": "stt_model/uk/vosk_hub/13-05-2022-07-03-vosk-model-uk-v3.zip",
            "domain": "general",
            "suburl": "uk-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need transcriptions that are accurate across domains.",
        }
    ],
    "de": [
        {
            "modelPath": "stt_model/de/vosk_hub/13-05-2022-07-01-vosk-model-de-0.21.zip",
            "domain": "general",
            "suburl": "de-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need transcriptions that are accurate across domains.",
        }
    ],
    "el": [
        {
            "modelPath": "stt_model/el/vosk_hub/13-05-2022-06-35-vosk-model-el-gr-0.7.zip",
            "domain": "general",
            "suburl": "el-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need transcriptions that are accurate across domains.",
        }
    ],
    "fa": [
        {
            "modelPath": "stt_model/fa/vosk_hub/13-05-2022-06-36-vosk-model-fa-0.5.zip",
            "domain": "general",
            "suburl": "fa-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need transcriptions that are accurate across domains.",
        }
    ],
    "nl": [
        {
            "modelPath": "stt_model/nl/vosk_hub/19-05-2022-15-16-vosk-model-nl-spraakherkenning-0.6.zip",
            "domain": "general",
            "suburl": "nl-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need transcriptions that are accurate across domains.",
        }
    ],
    "pt": [
        {
            "modelPath": "stt_model/pt/vosk_hub/20-04-2022-14-18-vosk-model-small-pt-0.3.zip",
            "domain": "general",
            "suburl": "pt-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need transcriptions that are accurate across domains.",
        }
    ],
    "es": [
        {
            "modelPath": "stt_model/es/vosk_hub/20-04-2022-14-24-vosk-model-small-es-0.22.zip",
            "domain": "general",
            "suburl": "es-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need transcriptions that are accurate across domains.",
        }
    ],
    "ca": [
        {
            "modelPath": "stt_model/ca/vosk_hub/20-04-2022-14-28-vosk-model-small-ca-0.4.zip",
            "domain": "general",
            "suburl": "ca-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need transcriptions that are accurate across domains.",
        }
    ],
    "cs": [
        {
            "modelPath": "stt_model/cs/vosk_hub/20-04-2022-14-55-vosk-model-small-cs-0.4-rhasspy.zip",
            "domain": "general",
            "suburl": "cs-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need transcriptions that are accurate across domains.",
        }
    ],
    "eo": [
        {
            "modelPath": "stt_model/eo/vosk_hub/19-05-2022-15-04-vosk-model-small-eo-0.22.zip",
            "domain": "general",
            "suburl": "eo-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need transcriptions that are accurate across domains.",
        }
    ],
    "ja": [
        {
            "modelPath": "stt_model/ja/vosk_hub/19-05-2022-15-05-vosk-model-small-ja-0.22.zip",
            "domain": "general",
            "suburl": "ja-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need transcriptions that are accurate across domains.",
        }
    ],
    "kk": [
        {
            "modelPath": "stt_model/kz/vosk_hub/13-05-2022-06-45-vosk-model-kz-0.15.zip",
            "domain": "general",
            "suburl": "kz-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need transcriptions that are accurate across domains.",
        }
    ],
    "tr": [
        {
            "modelPath": "stt_model/tr/vosk_hub/19-05-2022-14-53-vosk-model-small-tr-0.3.zip",
            "domain": "general",
            "suburl": "tr-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need transcriptions that are accurate across domains.",
        }
    ],
    "it": [
        {
            "modelPath": "stt_model/it/vosk_hub/21-04-2022-08-19-vosk-model-small-it-0.4.zip",
            "domain": "general",
            "suburl": "it-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need transcriptions that are accurate across domains.",
        }
    ],
    "vn": [
        {
            "modelPath": "stt_model/vn/vosk_hub/19-05-2022-14-57-vosk-model-small-vn-0.3.zip",
            "domain": "general",
            "suburl": "vn-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need transcriptions that are accurate across domains.",
        }
    ],
    "zh": [
        {
            "modelPath": "stt_model/cn/vosk_hub/19-05-2022-14-16-vosk-model-cn-kaldi-multicn-0.15.zip",
            "domain": "general",
            "suburl": "cn-16",
            "sampleRate": 16000,
            "description": "Select this domain if you need transcriptions that are accurate across domains.",
        }
    ],
    "or": [
        {
            "modelPath": "stt_model/or/vosk_hub/30-05-2022-07-19-in-or-mucs-char-lmor1-musan-8k.zip",
            "domain": "general",
            "suburl": "or-8",
            "sampleRate": 8000,
            "description": "Select this domain if you need transcriptions that are accurate across domains.",
        }
    ],
}
